@@ -64,6 +64,17 @@ WS_PAYLOAD={"Method":"",
             "ClientCode":"",
             "MarketFeedData":""}
 
+JWT_HEADERS={
+    'Ocp-Apim-Subscription-Key': 'c89fab8d895a426d9e00db380b433027',
+    'x-clientcode':"",
+    'x-auth-token':""
+    }
+
+JWT_PAYLOAD={
+    "ClientCode":"",
+    "JWTToken":""
+    }
+
 TODAY_TIMESTAMP = int(datetime.datetime.today().timestamp())
 NEXT_DAY_TIMESTAMP = int(
     (datetime.datetime.today()+datetime.timedelta(days=1)).timestamp())
